@@ -2,5 +2,5 @@ from .gpytranslate import Translator
 from .sync import SyncTranslator
 from .types import TranslatedObject
 
-__version__ = "1.1.0"
-__all__ = ["Translator", "SyncTranslator", "TranslatedObject"]
+__version__ = "1.2.0"
+__all__ = ["Translator", "SyncTranslator", "TranslatedObject", "__version__"]
